package agenda;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Random;
import java.util.Scanner;

import tipos.Empresa;
import tipos.Persona;
import es.uji.www.GeneradorDatosINE;

public final class Principal {
	private String[] opciones = {"1.- Genera una nueva Persona.",
			"2.- Genera una nueva Empresa.",
			"3.- Muestra todos los contactos.",
			"4.- Guarda la agenda en un fichero de texto.",
			"5.- Lee la agenda desde un fichero de texto",
			"0.- Salir del programa."};
	private static final String FICHERO = "agenda.txt";
	private static final int NUEVA_PERSONA = 1;
	private static final int NUEVA_EMPRESA = 2;
	private static final int MUESTRA_TODOS = 3;
	private static final int GUARDA_FICHERO_TEXTO = 4;
	private static final int LEE_FICHERO_TEXTO = 5;
	private static final int SALIR = 0;
	private Agenda agenda = new Agenda();
	private Scanner teclado = new Scanner(System.in);
	private GeneradorDatosINE generador = new GeneradorDatosINE();
	private Random telefonos = new Random();

	private Principal() {
		super();
	}

	private void ejecuta() {
		int opcion = 0;
		do {
			muestraMenuOpciones();
			opcion = filtraOpcion();
		} while(opcion != 0);
	}

	private void muestraMenuOpciones() {
		for(String opcion: opciones) {
			System.out.println(opcion);
		}
	}

	private int pideOpcion(int max) {
		int opcion;
		do {
			System.out.print("Elige una opcion: ");
			opcion = teclado.nextInt();
		} while(opcion < 0 || opcion > max);
		return opcion;
	}

	private int filtraOpcion() {
		int opcion = pideOpcion(opciones.length);
		switch (opcion) {
		case NUEVA_PERSONA:
			nuevaPersona();
			break;
		case NUEVA_EMPRESA:
			nuevaEmpresa();
			break;
		case MUESTRA_TODOS:
			muestraTodos();
			break;
		case GUARDA_FICHERO_TEXTO:
			guardaFicheroTexto();
			break;
		case LEE_FICHERO_TEXTO:
			leeFicheroTexto();
			break;
		case SALIR:
			salir();
			break;
		}
		return opcion;
	}

	private void leeFicheroTexto() {
		BufferedReader br = null;
		try {
			try {
				FileReader fr = new FileReader(FICHERO);
				br = new BufferedReader(fr);
				String linea;
				while((linea = br.readLine()) != null) {
					procesaLinea(linea);
				}
			} finally {
				br.close();
			}
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	private void procesaLinea(String linea) {
		String tokens[] = linea.split(": ");
		if(tokens[0].equals("Persona")) {
			agenda.nuevoContacto(new Persona(tokens[1], tokens[2], tokens[3]));
		} else if(tokens[0].equals("Empresa")) {
			agenda.nuevoContacto(new Empresa(tokens[1], tokens[2]));
		}
	}

	private void salir() {
		System.out.println("Ciao.");
	}

	private void muestraTodos() {
		for(int i = 0; i < agenda.getOcupacion(); i++)
			System.out.println(agenda.getContacto(i));
	}

	private void guardaFicheroTexto() {
		PrintWriter pw = null;
		try {
			pw = new PrintWriter(FICHERO);
			for(int i = 0; i < agenda.getOcupacion(); i++)
				pw.println(agenda.getContacto(i));
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} finally {
			if(pw != null) pw.close();
		}
	}

	private void nuevaPersona() {
		String nombre = generador.getNombre();
		String apellidos = generador.getApellido() + " " + generador.getApellido();
		String telefono = "" + telefonos.nextInt(1000000000);
		agenda.nuevoContacto(new Persona(nombre, apellidos, telefono));
	}

	private void nuevaEmpresa() {
		String nombre = generador.getNombre();
		String telefono = "" + telefonos.nextInt(1000000000);
		agenda.nuevoContacto(new Empresa(nombre, telefono));
	}

	public static void main(String[] args) {
		new Principal().ejecuta();
	}
}
