package persona.comentarios;

/** Implementacin de la clase Persona
 * Esta clase describe a un nuevo contacto 
 * en una agenda de telfonos
 * @author scar Belmonte Fernndez
 * @version 1.0
*/

public class Persona {
	private String nombre;
	private String apellidos;
	private String telefono;
	private static int nInstancias = 0;

	/**
	 * Constructor por defecto
	 */
	public Persona() {
		nInstancias++;
	}

	/**
	 * Constructor con parmetros.
	 * En nuevas versiones, tanto el nombre como los apellidos sern
	 * inmutables, no existirn mtodos para camobiarlos
	 * @param nombre Nombre del nuevo contacto
	 * @param apellidos Apellidos del nuevo contacto
	 * @param telefono Telfono del nuevo contacto
	 */
	public Persona(String nombre, String apellidos, String telefono) {
		this.nombre = nombre;
		this.apellidos = apellidos;
		this.telefono = telefono;
		nInstancias++;
	}
	
	/**
	 * Devuelve el nmero de instancias creadas
	 * @return El nmero de instancias
	 */
	public static int getNInstancias() {
		return nInstancias;
	}

	/**
	 * Devuelve el nombre del contacto
	 * @return Nombre del contacto
	 */
	public String getNombre() {
		return nombre;
	}
	
	/**
	 * Devuelve los apellidos del contacot
	 * @return Apellidos del contacto
	 */
	public String getApellidos() {
		return apellidos;
	}
	
	/**
	 * Devuelve el nmero de telfono del contacto
	 * @return Nmero de telfono del contacto
	 */
	public String getTelefono() {
		return telefono;
	}

	/**
	 * Cambia el nombre del contacto
	 * @param nombre El nuevo nombre del contacto
	 * @deprecated Este mtodo se eliminar en versiones futuras
	 * @see Persona(String nombre, String apellidos, String telefono)
	 */
	public void setNombre(String nombre) {
		this.nombre = nombre;
	}

	/**
	 * Cambia los apellidos del contacto
	 * @param apellidos Los nuevos apellidos del contacto
	 * @deprecated Este mtodo se eliminar en versiones futuras
	 * @see #Persona(String nombre, String apellidos, String telefono)
	 */
	public void setApellidos(String apellidos) {
		this.apellidos = apellidos;
	}

	/**
	 * Cambia el nmero de telfono del contacto
	 * @param telefono El nuevo nmero de telfono del contacto
	 */
	public void setTelefono(String telefono) {
		this.telefono = telefono;
	}
}
