package estructuras;

import java.util.concurrent.locks.Condition;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;

public class BufferConLock<T> implements Buffer<T> {
	private int cabeza = 0;
	private int capacidad;
	private Object datos[];
	private int ocupacion = 0;
	private Lock cerrojo;
	private Condition condicion;

	public BufferConLock(int capacidad) {
		super();
		this.capacidad = capacidad;
		datos = new Object[capacidad];
		cerrojo = new ReentrantLock();
		condicion = cerrojo.newCondition();
	}

	public BufferConLock(int capacidad, Lock cerrojo, Condition condicion) {
		super();
		this.capacidad = capacidad;
		datos = new Object[capacidad];
		this.cerrojo = cerrojo;
		this.condicion = condicion;
	}

	@SuppressWarnings("unchecked")
	@Override
	public T getDato(String cliente) throws InterruptedException {
		T dato;
		cerrojo.lock();
		try {
			while(ocupacion == 0)
				condicion.await();
			dato = (T)datos[cabeza];
			ocupacion--;
			cabeza++;
			cabeza %= capacidad;
			System.out.format("-%s(%s)[%d]\n", dato, cliente, ocupacion);
		} finally {
			condicion.signalAll();
			cerrojo.unlock();
		}
		return dato;
	}

	@Override
	public void setDato(T dato) throws InterruptedException {
		cerrojo.lock();
		try {
			while(ocupacion == capacidad)
				condicion.await();
			datos[(cabeza + ocupacion)%capacidad] = dato;
			ocupacion++;
			System.out.format("+%s[%d]\n", dato, ocupacion);
		} finally {
			condicion.signalAll();
			cerrojo.unlock();
		}
	}
}
