package estructuras;

import java.util.concurrent.locks.Condition;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;

public class TiendaConLock implements Tienda {
	private BufferConLock<Verduras> verduras;
	private BufferConLock<Carnes> carnes;
	private BufferConLock<Pescados> pescados;
	private Lock tendero;
	private Condition verdurasDisponibles;
	private Condition carnesDisponibles;
	private Condition pescadosDisponibles;
	
	public TiendaConLock() {
		super();
		tendero = new ReentrantLock();
		verdurasDisponibles = tendero.newCondition();
		carnesDisponibles = tendero.newCondition();
		pescadosDisponibles = tendero.newCondition();
		verduras = new BufferConLock<Verduras>(10, tendero, verdurasDisponibles);
		carnes = new BufferConLock<Carnes>(10, tendero, carnesDisponibles);
		pescados = new BufferConLock<Pescados>(10, tendero, pescadosDisponibles);
	}
	
	public Lock getTendero() {
		return tendero;
	}
	
	public Verduras compraVerdura(String cliente) throws InterruptedException {
		return verduras.getDato(cliente);
	}
	
	public Carnes compraCarne(String cliente) throws InterruptedException {
		return carnes.getDato(cliente);
	}
	
	public Pescados compraPescado(String cliente) throws InterruptedException {
		return pescados.getDato(cliente);
	}
	
	public void abasteceVerdura(Verduras dato) throws InterruptedException {
		verduras.setDato(dato);
	}
	
	public void abasteceCarne(Carnes dato) throws InterruptedException {
		carnes.setDato(dato);
	}
	
	public void abastecePescado(Pescados dato) throws InterruptedException {
		pescados.setDato(dato);
	}
	
	public void cierraTienda() {
		verdurasDisponibles.signalAll();
		pescadosDisponibles.signalAll();
		carnesDisponibles.signalAll();
	}
}
